##  Track Data Completeness with the Completion Score
The fact sheet completion score measures how much of the required data has been filled out for a fact sheet. It helps you identify which fact sheets are well-completed and which ones need more information. It ensures the accuracy and completeness of the data in SAP LeanIX, which is crucial for effective enterprise architecture management.
The fact sheet completion score is calculated based on the weights assigned to each field, subsection, and section. A higher weight signifies greater importance, meaning that completing those fields or subsections will have a more significant effect on the score. By default, weights are set to 0 or 1, but admins can adjust them as needed to highlight the importance of specific fields.
You can view the fact sheet's completion score in the fact sheet’s header. It reflects the extent to which all required fields, subsections, and sections are completed based on the configured weights.
For a detailed guide, see [Fact Sheet Completeness](https://help.sap.com/docs/leanix/ea/fact-sheet-completeness?locale=en-US&state=PRODUCTION&version=CLOUD "The fact sheet completion score measures the extent of required data filled out for a fact sheet, ensuring data accuracy and completeness. It is based on assigned weights to fields, subsections, and sections.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio25c770c9fa9c452f90b3d0ae0c64e24f_LowRes.png)
Completion Score on a Fact Sheet
### Configure Completion Weights
Set the completion weight for the following fields to 1. To learn how to do this, see [Modifying Completion Weights](https://help.sap.com/docs/leanix/ea/fact-sheet-completeness?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759f7fe7a441014aee8db7e808d0e4f__modifying_the_completion_weights).
  * Name
  * Description
  * Lifecycle
  * Functional Fit
  * Technical Fit
  * Business Criticality


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
